==> haskell-wreq-0.5.4.3-217-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wreq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wreq
version:              0.5.4.3
visibility:           public
id:                   wreq-0.5.4.3-HGBeKUwmD5oBjVss8WDQOG
key:                  wreq-0.5.4.3-HGBeKUwmD5oBjVss8WDQOG
license:              BSD-3-Clause
copyright:            2014 Bryan O'\''Sullivan
maintainer:           bos@serpentine.com
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://www.serpentine.com/wreq
synopsis:             An easy-to-use HTTP client library.
description:
    .
    A web client library that is designed for ease of use.
    .
    Tutorial: <http://www.serpentine.com/wreq/tutorial.html>
    .
    Features include:
    .
    * Simple but powerful `lens`-based API
    .
    * A solid test suite, and built on reliable libraries like
      http-client and lens
    .
    * Session handling includes connection keep-alive and pooling, and
      cookie persistence
    .
    * Automatic response body decompression
    .
    * Powerful multipart form and file upload handling
    .
    * Support for JSON requests and responses, including navigation of
      schema-less responses
    .
    * Basic and OAuth2 bearer authentication
    .
    * Early TLS support via the tls package

category:             Web
abi:                  d974b41948ee85cced14df4578f3e573
exposed:              True
exposed-modules:
    Network.Wreq Network.Wreq.Cache Network.Wreq.Cache.Store
    Network.Wreq.Lens Network.Wreq.Session Network.Wreq.Types

hidden-modules:
    Network.Wreq.Internal Network.Wreq.Internal.AWS
    Network.Wreq.Internal.Lens Network.Wreq.Internal.Link
    Network.Wreq.Internal.OAuth1 Network.Wreq.Internal.Types
    Network.Wreq.Lens.Machinery Network.Wreq.Lens.TH Paths_wreq

import-dirs:          /usr/lib/ghc-9.6.6/site-local/wreq-0.5.4.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wreq-0.5.4.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wreq-0.5.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wreq
hs-libraries:         HSwreq-0.5.4.3-HGBeKUwmD5oBjVss8WDQOG
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm
    authenticate-oauth-1.7-LVfJbbsaaAM8EUlBSEN0UV base-4.18.2.1
    base16-bytestring-1.0.2.0-Dwd5n4mSUH32rjuqPFOreR
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-3fPl2hvou1nDiCO1iE2i5z
    containers-0.6.7 crypton-1.0.4-11gen3PFWz54w2m32bVEwY
    exceptions-0.10.7 ghc-prim-0.10.0
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    http-client-0.7.19-ITPZXASBEGHLmOi4NfdGY8
    http-client-tls-0.3.6.4-2TpGPIcpPZAJDvilQsJ18b
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM
    lens-aeson-1.2.3-FAgRYVuU5157AZ98ZS6OOm
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    mime-types-0.1.2.0-2lnuHjhOzQ4DFNhuFJ9ART
    psqueues-0.2.8.2-7Hsdb7lcqdu8EEvCE8H06F template-haskell-2.20.0.0
    text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-8XUEctZKps57K6Zw5siYoh
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:   /usr/share/doc/haskell-wreq/html/wreq.haddock
haddock-html:         /usr/share/doc/haskell-wreq/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wreq-0.5.4.3-218-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wreq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wreq
version:              0.5.4.3
visibility:           public
id:                   wreq-0.5.4.3-DTdy7XMZgjM4RAlV1fNqAn
key:                  wreq-0.5.4.3-DTdy7XMZgjM4RAlV1fNqAn
license:              BSD-3-Clause
copyright:            2014 Bryan O'\''Sullivan
maintainer:           bos@serpentine.com
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://www.serpentine.com/wreq
synopsis:             An easy-to-use HTTP client library.
description:
    .
    A web client library that is designed for ease of use.
    .
    Tutorial: <http://www.serpentine.com/wreq/tutorial.html>
    .
    Features include:
    .
    * Simple but powerful `lens`-based API
    .
    * A solid test suite, and built on reliable libraries like
      http-client and lens
    .
    * Session handling includes connection keep-alive and pooling, and
      cookie persistence
    .
    * Automatic response body decompression
    .
    * Powerful multipart form and file upload handling
    .
    * Support for JSON requests and responses, including navigation of
      schema-less responses
    .
    * Basic and OAuth2 bearer authentication
    .
    * Early TLS support via the tls package

category:             Web
abi:                  977fbfadec89f47ae98738311fc8e645
exposed:              True
exposed-modules:
    Network.Wreq Network.Wreq.Cache Network.Wreq.Cache.Store
    Network.Wreq.Lens Network.Wreq.Session Network.Wreq.Types

hidden-modules:
    Network.Wreq.Internal Network.Wreq.Internal.AWS
    Network.Wreq.Internal.Lens Network.Wreq.Internal.Link
    Network.Wreq.Internal.OAuth1 Network.Wreq.Internal.Types
    Network.Wreq.Lens.Machinery Network.Wreq.Lens.TH Paths_wreq

import-dirs:          /usr/lib/ghc-9.6.6/site-local/wreq-0.5.4.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wreq-0.5.4.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wreq-0.5.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wreq
hs-libraries:         HSwreq-0.5.4.3-DTdy7XMZgjM4RAlV1fNqAn
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE
    authenticate-oauth-1.7-Q4xD21IK8fI8kc0KhYJUM base-4.18.2.1
    base16-bytestring-1.0.2.0-ARBAmNNbyxLEDoUwDjra0R
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-KNymwxzPyypAOJSQGx0ioI
    containers-0.6.7 crypton-1.0.4-8iIZddQo7Y8B1JLRcnCUbI
    exceptions-0.10.7 ghc-prim-0.10.0
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    http-client-0.7.19-9XP2fRtq348Edv4XKGE8tD
    http-client-tls-0.3.6.4-GXwyMNGv8mPI3u8Rlj5noc
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB
    lens-aeson-1.2.3-4ImEZjcSS5v7sGC7rUGMR2
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    mime-types-0.1.2.0-2lnuHjhOzQ4DFNhuFJ9ART
    psqueues-0.2.8.2-8uu3DxPW2eP1IKqIpq0lUH template-haskell-2.20.0.0
    text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-8XUEctZKps57K6Zw5siYoh
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:   /usr/share/doc/haskell-wreq/html/wreq.haddock
haddock-html:         /usr/share/doc/haskell-wreq/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
